package main

import (
	"bytes"
	"encoding/json"
	"fmt"
	"io"
	"io/ioutil"
	"os"
	"strings"

	"github.com/ghodss/yaml"
)

func main() {
	var f io.ReadCloser
	if len(os.Args) > 1 {
		a, err := os.Open(os.Args[1])
		if err != nil {
			fatal(err)
		}
		f = a
	} else {
		stat, _ := os.Stdin.Stat()
		if (stat.Mode() & os.ModeCharDevice) != 0 {
			fatal("no data to read")
		}
		f = os.Stdin
	}
	defer f.Close()
	b, err := ioutil.ReadAll(f)
	if err != nil {
		fatal(err)
	}
	if strings.HasPrefix(strings.TrimSpace(string(b)), "{") {
		yb, err := yaml.JSONToYAML(b)
		if err != nil {
			fatal("failed to convert")
		}
		fmt.Println(string(yb))
		return
	}
	var t interface{}
	if err := yaml.Unmarshal(b, &t); err != nil {
		fatal(err)
	}
	buff := bytes.Buffer{}
	e := json.NewEncoder(&buff)
	e.SetEscapeHTML(false)
	e.SetIndent("", "    ")
	if err := e.Encode(t); err != nil {
		fatal(err)
	}
	fmt.Println(buff.String())

}

func fatal(m interface{}) {
	fmt.Println(m)
	os.Exit(1)
}
